==> huaweicloudsdkroma-3.0.83-py2.py3-none-any.whl: huaweicloudsdkroma/v2/model/list_datasource_columns_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDatasourceColumnsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'columns': 'list[ColumnInfo]'
    }

    attribute_map = {
        'columns': 'columns'
    }

    def __init__(self, columns=None):
        """ListDatasourceColumnsResponse - a model defined in huaweicloud sdk"""
        
        super(ListDatasourceColumnsResponse, self).__init__()

        self._columns = None
        self.discriminator = None

        if columns is not None:
            self.columns = columns

    @property
    def columns(self):
        """Gets the columns of this ListDatasourceColumnsResponse.

        返回的实体对象

        :return: The columns of this ListDatasourceColumnsResponse.
        :rtype: list[ColumnInfo]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this ListDatasourceColumnsResponse.

        返回的实体对象

        :param columns: The columns of this ListDatasourceColumnsResponse.
        :type: list[ColumnInfo]
        """
        self._columns = columns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDatasourceColumnsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkroma-3.0.89-py2.py3-none-any.whl: huaweicloudsdkroma/v2/model/list_datasource_columns_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDatasourceColumnsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'columns': 'list[ColumnInfo]'
    }

    attribute_map = {
        'columns': 'columns'
    }

    def __init__(self, columns=None):
        """ListDatasourceColumnsResponse

        The model defined in huaweicloud sdk

        :param columns: 返回的实体对象
        :type columns: list[:class:`huaweicloudsdkroma.v2.ColumnInfo`]
        """
        
        super(ListDatasourceColumnsResponse, self).__init__()

        self._columns = None
        self.discriminator = None

        if columns is not None:
            self.columns = columns

    @property
    def columns(self):
        """Gets the columns of this ListDatasourceColumnsResponse.

        返回的实体对象

        :return: The columns of this ListDatasourceColumnsResponse.
        :rtype: list[:class:`huaweicloudsdkroma.v2.ColumnInfo`]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """Sets the columns of this ListDatasourceColumnsResponse.

        返回的实体对象

        :param columns: The columns of this ListDatasourceColumnsResponse.
        :type columns: list[:class:`huaweicloudsdkroma.v2.ColumnInfo`]
        """
        self._columns = columns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDatasourceColumnsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
